@@ -1,8 +1,9 @@
 """Definitions for the `TDEConstraints` class."""
-from mosfit.constants import M_SUN_CGS, C_CGS
-from mosfit.modules.constraints.constraint import Constraint
 import astropy.constants as c
 
+from mosfit.constants import C_CGS, M_SUN_CGS
+from mosfit.modules.constraints.constraint import Constraint
+
 
 class TDEConstraints(Constraint):
     """TDE constraints.
@@ -21,13 +22,13 @@ class TDEConstraints(Constraint):
         self._score_modifier = 0.0
         self._rp = kwargs[self.key('rp')]  # already in cgs
         self._bhmass = kwargs['bhmass']
-        self._Rs = c.G.cgs.value*self._bhmass*M_SUN_CGS/(C_CGS*C_CGS)
+        self._Rs = c.G.cgs.value * self._bhmass * M_SUN_CGS / (C_CGS * C_CGS)
 
         # Pericenter radius is getting close to Schwarzschild radius
-        if (self._Rs/self._rp > 0.1):
+        if (self._Rs / self._rp > 0.1):
             # soft limit
             self._score_modifier += - (
-                self._Rs/self._rp * self._max_modification)/(
-                self._Rs/self._rp + self._max_modification)
+                self._Rs / self._rp * self._max_modification) / (
+                self._Rs / self._rp + self._max_modification)
 
         return {self.key('score_modifier'): self._score_modifier}
